==> Meta-0.03.tar.gz: Meta-0.03/Meta/Baseline/Lang/Txtx.pm <==
#!/bin/echo This is a perl module and should not be run

package Meta::Baseline::Lang::Txtx;

use strict qw(vars refs subs);
use Meta::Baseline::Utils qw();
use Meta::Baseline::Lang qw();
use Meta::Tool::Aspell qw();
use Meta::Tool::Gzip qw();

our($VERSION,@ISA);
$VERSION="0.28";
@ISA=qw(Meta::Baseline::Lang);

#sub c2chec($);
#sub c2gzxx($);
#sub my_file($$);

#__DATA__

sub c2chec($) {
	my($buil)=@_;
	my($resu)=1;
	if(!Meta::Tool::Aspell::checktxt($buil)) {
		$resu=0;
	}
	if($resu) {
		Meta::Baseline::Utils::file_emblem($buil->get_targ());
	}
	return($resu);
}

sub c2gzxx($) {
	my($buil)=@_;
	return(Meta::Tool::Gzip::c2gzxx($buil));
}

sub my_file($$) {
	my($self,$file)=@_;
	if($file=~/^txtx\/.*\.txt$/) {
		return(1);
	} else {
		return(0);
	}
}

1;

__END__

=head1 NAME

Meta::Baseline::Lang::Txtx - doing Text specific stuff in the baseline.

=head1 COPYRIGHT

Copyright (C) 2001, 2002 Mark Veltzer;
All rights reserved.

=head1 LICENSE

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.

=head1 DETAILS

	MANIFEST: Txtx.pm
	PROJECT: meta
	VERSION: 0.28

=head1 SYNOPSIS

	package foo;
	use Meta::Baseline::Lang::Txtx qw();
	my($result)=Meta::Baseline::Lang::Txtx::c2chec("myfile.txt");

=head1 DESCRIPTION

This package does Text specific things in the baseline.
Things that it does:
0. validation of text files.
	a. spelling validation using in baseline dictionaries.
	b. validation that the text files are UNIX type text files.
	c. validation that there are not forbidden characters in the file.

=head1 FUNCTIONS

	c2chec($)
	c2gzxx($)
	my_file($$)

=head1 FUNCTION DOCUMENTATION

=over 4

=item B<c2chec($)>

This will check the following:
Spelling, forbidden seqeunces.

=item B<c2gzxx($)>

This method will convert source files to compressed source files.
It uses the Tool::Gzip class.

=item B<my_file($$)>

This method will return true if the file received should be handled by this
module.

=back

=head1 BUGS

None.

=head1 AUTHOR

	Name: Mark Veltzer
	Email: mark2776@yahoo.com
	WWW: http://www.geocities.com/mark2776
	CPAN id: VELTZER

=head1 HISTORY

	0.00 MV initial code brought in
	0.01 MV make quality checks on perl code
	0.02 MV more perl checks
	0.03 MV check that all uses have qw
	0.04 MV fix todo items look in pod documentation
	0.05 MV more on tests/more checks to perl
	0.06 MV text change
	0.07 MV perl quality change
	0.08 MV perl code quality
	0.09 MV more perl quality
	0.10 MV more perl quality
	0.11 MV perl documentation
	0.12 MV more perl quality
	0.13 MV perl qulity code
	0.14 MV more perl code quality
	0.15 MV revision change
	0.16 MV revision for perl files and better sanity checks
	0.17 MV languages.pl test online
	0.18 MV add rtf format to website,work on papers,add dtd lang
	0.19 MV fix docbook and other various stuff
	0.20 MV add zipping subsystem
	0.21 MV perl packaging
	0.22 MV BuildInfo object change
	0.23 MV md5 project
	0.24 MV database
	0.25 MV perl module versions in files
	0.26 MV movies and small fixes
	0.27 MV thumbnail user interface
	0.28 MV more thumbnail issues

=head1 SEE ALSO

Nothing.

=head1 TODO

Nothing.

==> Meta-0.06.tar.gz: Meta-0.06/Meta/Baseline/Lang/Txtx.pm <==
#!/bin/echo This is a perl module and should not be run

package Meta::Baseline::Lang::Txtx;

use strict qw(vars refs subs);
use Meta::Baseline::Utils qw();
use Meta::Baseline::Lang qw();
use Meta::Tool::Aspell qw();

our($VERSION,@ISA);
$VERSION="0.31";
@ISA=qw(Meta::Baseline::Lang);

#sub c2chec($);
#sub my_file($$);
#sub TEST($);

#__DATA__

sub c2chec($) {
	my($buil)=@_;
	my($resu)=1;
	if(!Meta::Tool::Aspell::checktxt($buil)) {
		$resu=0;
	}
	if($resu) {
		Meta::Baseline::Utils::file_emblem($buil->get_targ());
	}
	return($resu);
}

sub my_file($$) {
	my($self,$file)=@_;
	if($file=~/^txtx\/.*\.txt$/) {
		return(1);
	} else {
		return(0);
	}
}

sub TEST($) {
	my($context)=@_;
	return(1);
}

1;

__END__

=head1 NAME

Meta::Baseline::Lang::Txtx - doing Text specific stuff in the baseline.

=head1 COPYRIGHT

Copyright (C) 2001, 2002 Mark Veltzer;
All rights reserved.

=head1 LICENSE

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.

=head1 DETAILS

	MANIFEST: Txtx.pm
	PROJECT: meta
	VERSION: 0.31

=head1 SYNOPSIS

	package foo;
	use Meta::Baseline::Lang::Txtx qw();
	my($result)=Meta::Baseline::Lang::Txtx::c2chec("myfile.txt");

=head1 DESCRIPTION

This package does Text specific things in the baseline.
Things that it does:
0. validation of text files.
	a. spelling validation using in baseline dictionaries.
	b. validation that the text files are UNIX type text files.
	c. validation that there are not forbidden characters in the file.

=head1 FUNCTIONS

	c2chec($)
	my_file($$)
	TEST($)

=head1 FUNCTION DOCUMENTATION

=over 4

=item B<c2chec($)>

This will check the following:
Spelling, forbidden seqeunces.

=item B<my_file($$)>

This method will return true if the file received should be handled by this
module.

=item B<TEST($)>

Test suite for this module.

=back

=head1 SUPER CLASSES

Meta::Baseline::Lang(3)

=head1 BUGS

None.

=head1 AUTHOR

	Name: Mark Veltzer
	Email: mailto:veltzer@cpan.org
	WWW: http://www.veltzer.org
	CPAN id: VELTZER

=head1 HISTORY

	0.00 MV initial code brought in
	0.01 MV make quality checks on perl code
	0.02 MV more perl checks
	0.03 MV check that all uses have qw
	0.04 MV fix todo items look in pod documentation
	0.05 MV more on tests/more checks to perl
	0.06 MV text change
	0.07 MV perl quality change
	0.08 MV perl code quality
	0.09 MV more perl quality
	0.10 MV more perl quality
	0.11 MV perl documentation
	0.12 MV more perl quality
	0.13 MV perl qulity code
	0.14 MV more perl code quality
	0.15 MV revision change
	0.16 MV revision for perl files and better sanity checks
	0.17 MV languages.pl test online
	0.18 MV add rtf format to website,work on papers,add dtd lang
	0.19 MV fix docbook and other various stuff
	0.20 MV add zipping subsystem
	0.21 MV perl packaging
	0.22 MV BuildInfo object change
	0.23 MV md5 project
	0.24 MV database
	0.25 MV perl module versions in files
	0.26 MV movies and small fixes
	0.27 MV thumbnail user interface
	0.28 MV more thumbnail issues
	0.29 MV website construction
	0.30 MV web site automation
	0.31 MV SEE ALSO section fix

=head1 SEE ALSO

Meta::Baseline::Lang(3), Meta::Baseline::Utils(3), Meta::Tool::Aspell(3), strict(3)

=head1 TODO

Nothing.
